@@ -48,6 +48,17 @@ class HeatStacksTestCase(test.TestCase):
         self._test_atomic_action_timer(
             heat_scenario.atomic_actions(), "heat.list_resources_of_1_stacks")
 
+    @mock.patch(HEAT_STACKS + ".clients")
+    @mock.patch(HEAT_STACKS + "._list_stacks")
+    def test_list_stack_and_events(self, mock_list_stack, mock_clients):
+        stack = mock.Mock()
+        mock_list_stack.return_value = [stack]
+        heat_scenario = stacks.HeatStacks()
+        heat_scenario.list_stacks_and_events()
+        mock_clients("heat").events.list.assert_called_once_with(stack.id)
+        self._test_atomic_action_timer(
+            heat_scenario.atomic_actions(), "heat.list_events_of_1_stacks")
+
     @mock.patch(HEAT_STACKS + "._generate_random_name")
     @mock.patch(HEAT_STACKS + "._list_stacks")
     @mock.patch(HEAT_STACKS + "._create_stack")
@@ -120,4 +131,4 @@ class HeatStacksTestCase(test.TestCase):
         mock_resume.assert_called_once_with(
             "fake_stack_create_suspend_resume_delete")
         mock_delete.assert_called_once_with(
-            "fake_stack_create_suspend_resume_delete")
\ No newline at end of file
+            "fake_stack_create_suspend_resume_delete")
